@@ -9,7 +9,7 @@
 package Dist::Zilla::Plugin::Git::GatherDir;
 # ABSTRACT: Gather all tracked files in a Git working directory
 
-our $VERSION = '2.042';
+our $VERSION = '2.044';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::GatherDir' => { -version => 4.200016 }; # exclude_match
@@ -31,8 +31,7 @@ extends 'Dist::Zilla::Plugin::GatherDir' => { -version => 4.200016 }; # exclude_
 #pod This is a trivial variant of the L<GatherDir|Dist::Zilla::Plugin::GatherDir>
 #pod plugin.  It looks in the directory named in the L</root> attribute and adds all
 #pod the Git tracked files it finds there (as determined by C<git ls-files>).  If the
-#pod root begins with a tilde, the tilde is replaced with the current user's home
-#pod directory according to L<File::HomeDir>.
+#pod root begins with a tilde, the tilde portion is passed through C<glob()> first.
 #pod
 #pod Most users just need:
 #pod
@@ -140,6 +139,7 @@ around dump_config => sub
 
     $config->{+__PACKAGE__} = {
         include_untracked => $self->include_untracked ? 1 : 0,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -151,16 +151,13 @@ override gather_files => sub {
   require Git::Wrapper;
   require Path::Tiny;
 
-  my $root = "" . $self->root;
-  # Convert ~ to home directory:
-  if ($root =~ /^~/) {
-    require File::HomeDir;
-    File::HomeDir->VERSION(0.81);
+  my $root = '' . $self->root;
 
-    $root =~ s/^~(\w+)/ File::HomeDir->users_home("$1") /e;
-    $root =~ s/^~/      File::HomeDir->my_home /e;
-  } # end if $root begins with ~
-  $root = Path::Tiny::path($root)->absolute($self->zilla->root->absolute);
+  # Convert ~ portion to real directory:
+  $root =~ s{^(~[^\\/]*)([\\/])}{$self->_homedir($1) . $2}e;
+
+  $root = Path::Tiny::path($root);
+  $root = $root->absolute($self->zilla->root->absolute);
 
   # Prepare to gather files
   my $git = Git::Wrapper->new($root->stringify);
@@ -212,6 +209,19 @@ override gather_files => sub {
   return;
 };
 
+sub _homedir {
+  my ($self, $tilde_dir) = @_;
+
+  # other architectures have no issue with globbing any kind of ~user path
+  return (glob($tilde_dir))[0] if $^O ne 'Win32';
+
+  # on Win32, we can use the environment variable(s) for the current user
+  return "$]" < '5.016' ? $ENV{HOME} || $ENV{USERPROFILE} : (glob('~'))[0]
+    if $tilde_dir eq '~';
+
+  # but otherwise, we can't support this at all, on any version.
+  $self->log_fatal('expanding "' . $tilde_dir . '" on Win32 not supported');
+}
 
 __PACKAGE__->meta->make_immutable;
 no Moose;
@@ -229,7 +239,7 @@ Dist::Zilla::Plugin::Git::GatherDir - Gather all tracked files in a Git working
 
 =head1 VERSION
 
-version 2.042
+version 2.044
 
 =head1 SYNOPSIS
 
@@ -248,8 +258,7 @@ In your F<dist.ini>:
 This is a trivial variant of the L<GatherDir|Dist::Zilla::Plugin::GatherDir>
 plugin.  It looks in the directory named in the L</root> attribute and adds all
 the Git tracked files it finds there (as determined by C<git ls-files>).  If the
-root begins with a tilde, the tilde is replaced with the current user's home
-directory according to L<File::HomeDir>.
+root begins with a tilde, the tilde portion is passed through C<glob()> first.
 
 Most users just need:
 
