@@ -12,7 +12,7 @@ use warnings;
 package Dist::Zilla::Plugin::Git::NextVersion;
 # ABSTRACT: Provide a version number by bumping the last git release tag
 
-our $VERSION = '2.042';
+our $VERSION = '2.044';
 
 use Dist::Zilla 4 ();
 use version 0.80 ();
@@ -40,12 +40,12 @@ use constant _CoercedRegexp => do {
     $tc;
 };
 
-has version_regexp  => ( is => 'ro', isa=> _CoercedRegexp, coerce => 1,
+has version_regexp  => ( is => 'ro', isa => _CoercedRegexp, coerce => 1,
                          default => sub { qr/^v(.+)$/ } );
 
-has first_version  => ( is => 'ro', isa=>Str, default => '0.001' );
+has first_version  => ( is => 'ro', isa => Str, default => '0.001' );
 
-has version_by_branch  => ( is => 'ro', isa=>Bool, default => 0 );
+has version_by_branch  => ( is => 'ro', isa => Bool, default => 0 );
 
 sub _versions_from_tags {
   my ($regexp, $tags) = @_;
@@ -56,7 +56,9 @@ sub _versions_from_tags {
 } # end _versions_from_tags
 
 has _all_versions => (
-  is => 'ro',  isa=>ArrayRef,  init_arg => undef,  lazy => 1,
+  is => 'ro',  isa => ArrayRef,
+  init_arg => undef,
+  lazy => 1,
   default => sub {
     my $self = shift;
     my $v = _versions_from_tags($self->version_regexp, [ $self->git->tag ]);
@@ -86,7 +88,7 @@ sub _last_version {
 
   if ($by_branch) {
     my $head;
-    my $cachefile = path(_cache_fn);
+    my $cachefile = $self->zilla->root->child(_cache_fn);
     if (-f $cachefile) {
       ($head) = $git->rev_parse('HEAD');
       return $1 if $cachefile->slurp =~ /^\Q$head\E (.+)/;
@@ -133,6 +135,7 @@ around dump_config => sub
     $config->{+__PACKAGE__} = {
         (map { $_ => $self->$_ } qw(version_regexp first_version)),
         version_by_branch => $self->version_by_branch ? 1 : 0,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -205,7 +208,7 @@ Dist::Zilla::Plugin::Git::NextVersion - Provide a version number by bumping the
 
 =head1 VERSION
 
-version 2.042
+version 2.044
 
 =head1 SYNOPSIS
 
@@ -267,7 +270,7 @@ the last tag is 0.005 and you want to jump to 1.000 you can set V = 1.000.
 
 Because tracing history takes time, if you use the
 C<version_by_branch> option, Git::NextVersion will create a
-F<.gitnxtver_cache> file in your repository to track the highest
+F<.gitnxtver_cache> file in your repository root to track the highest
 version number that is an ancestor of the HEAD revision.  You should
 add F<.gitnxtver_cache> to your F<.gitignore> file.  It will
 automatically be pruned from the distribution.
