@@ -13,7 +13,7 @@ use warnings;
 package Dist::Zilla::Plugin::Git::Tag;
 # ABSTRACT: Tag the new version
 
-our $VERSION = '2.042';
+our $VERSION = '2.044';
 
 use Moose;
 use MooseX::Has::Sugar;
@@ -68,6 +68,7 @@ around dump_config => sub
     $config->{+__PACKAGE__} = {
         (map { $_ => $self->$_ } qw(tag_format tag_message changelog branch tag)),
         signed => $self->signed ? 1 : 0,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -99,6 +100,7 @@ sub after_release {
     $self->log("Tagged $tag");
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -113,7 +115,7 @@ Dist::Zilla::Plugin::Git::Tag - Tag the new version
 
 =head1 VERSION
 
-version 2.042
+version 2.044
 
 =head1 SYNOPSIS
 
